% nullstellen.m
% Kap. 7.3
% Nullstellenbestimmung skalarer und vektorwertiger Funktionen,
% sowie Lsen von Gleichungssystemen

format compact

% Nullstellen der skalaren Funktion funktion1.m

% funktion1.m grafisch darstellen
x=-2.5:0.1:2;
plot(x,funktion1(x))
axis([-3 2 -10 20]); set(gca,'xtick',[-3 -2 -1 0 1 2])
grid on
xlabel('x')
ylabel('f(x)')
title('funktion1.m')
% exportfig(gcf,'poly1.eps','width', 18, 'height', 9)


pause


% Nullstellensuche mit Anfangswert
x0 = 0; [nullst fwert] = fzero(@funktion1, x0)
x0 = -0.8; [nullst fwert] = fzero(@funktion1, x0)

% Nullstellensuche mit Suchintervall
x01=[-2.5 -2]; x02=[-1.5 -1]; x03=[0 0.5]; x04=[1.5 2];
options=optimset(@fzero); options=optimset('Display','final');

[nullst1 fwert1] = fzero(@funktion1, x01, options)
pause
[nullst2 fwert2] = fzero(@funktion1, x02, options),
pause
[nullst3 fwert3] = fzero(@funktion1, x03, options),
pause
[nullst4 fwert4] = fzero(@funktion1, x04, options)


pause


% Toleranz verndern

x04=[1.5 2];
tol=1e-3; options=optimset(@fzero); 
options=optimset(options,'TolX',tol,'Display','final');
[nullst4 fwert4] = fzero(@funktion1, x04, options)

pause

% Nullstellen mit roots bestimmen
poly = [1 1 -3 0 -1 -6 1]; 
nullst = roots(poly)


pause


% Nullstellenbestimmung von funktion2

% funktion2 als inline object definieren
funktion2 = inline('atan(x)-0.5.*x','x');

% funktion2 grafisch darstellen
x=-3:0.1:3;
plot(x,funktion2(x))
grid on
% exportfig(gcf,'poly1.eps','width', 18, 'height', 9)

pause

% Bestimmung der Nullstellen von funktion2
options=optimset(@fzero); options=optimset('Display','final');
x01 = [-3 -1]; nullst1 = fzero(funktion2, x01, options)
pause
x02 = [-1 1]; nullst2 = fzero(funktion2, x02, options)
pause
x03 = [2 3]; nullst3 = fzero(funktion2, x03, options)


pause


% Nullstellenbestimmung mit Parameterbergabe
x0=[1 2];
options=optimset(@fzero);
p1 = 1; p2 = 3;
x = fzero(@f_param,x0,options,p1,p2)


pause


% Lsen eines linearen Gleichungssystems

A = [1 2 3; 2 3 6; 3 2 7]

b = [1; 3; 0]

x = A\b

determinante = det(A)


pause


% Lsen des nichtlinearen Gleichungssystems in funktion3.m
% Startwert x0 = [1 1]

x0 = [1 1]; 
options = optimset(@fsolve); 
options = optimset(options, 'Display', 'iter');
[x, fval, exitflag] = fsolve(@funktion3, x0, options)


pause


% Startwert weiter von der Lsung entfernt 
% Startwert x0 = [10 10]

x0 = [10 10];
options = optimset(@fsolve); 
options = optimset(options, 'Display', 'iter');
[x, fval, exitflag] = fsolve(@funktion3, x0, options)


pause


% zweite Lsung durch anderen Startwert
% Startwert x0 = [-2 2]

x0 = [-2 2];
options = optimset(@fsolve); 
options = optimset(options, 'Display', 'final');
[x, fval, exitflag] = fsolve(@funktion3, x0, options)


pause


% Optimierung mit vorgegebener Jacobi-Matrix
% funktion4.m liefer zustzlich zu funktion3 
% die Jacobi-Matrix

x0 = [-2 2]; options = optimset(@fsolve); 
options = optimset(options, 'Display', 'iter', 'Jacobian', 'on');
[x, fval, exitflag] = fsolve(@funktion4, x0, options)
